# `rick-portal-gun`

Awesome Portal Gun

**Usage**:

```console
$ rick-portal-gun [OPTIONS] COMMAND [ARGS]...
```

**Options**:

* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.

**Commands**:

* `load`: Load the portal gun
* `shoot`: Shoot the portal gun

## `rick-portal-gun load`

Load the portal gun

**Usage**:

```console
$ rick-portal-gun load [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.

## `rick-portal-gun shoot`

Shoot the portal gun

**Usage**:

```console
$ rick-portal-gun shoot [OPTIONS]
```

**Options**:

* `--help`: Show this message and exit.
